@@ -38,7 +38,7 @@ namespace Tomboy
 
 		public NoteManager (string directory, string backup_directory)
 		{
-			Logger.Log ("NoteManager created with note path \"{0}\".", directory);
+			Logger.Debug ("NoteManager created with note path \"{0}\".", directory);
 
 			notes_dir = directory;
 			backup_dir = backup_directory;
@@ -246,6 +246,12 @@ Ciao!");
 			this.notes.Sort (new CompareDates ());
 		}
 
+		void OnBufferChanged (Note note)
+		{
+			if (NoteBufferChanged != null)
+				NoteBufferChanged (note);
+		}
+
 		protected virtual void CreateStartNotes ()
 		{
 			// FIXME: Delay the creation of the start notes so the panel/tray
@@ -309,6 +315,7 @@ Ciao!");
 
 		protected virtual void LoadNotes ()
 		{
+			Logger.Debug ("Loading notes");
 			string [] files = Directory.GetFiles (notes_dir, "*.note");
 
 			foreach (string file_path in files) {
@@ -317,13 +324,40 @@ Ciao!");
 					if (note != null) {
 						note.Renamed += OnNoteRename;
 						note.Saved += OnNoteSave;
+						note.BufferChanged += OnBufferChanged;
 						notes.Add (note);
 					}
 				} catch (System.Xml.XmlException e) {
-					Logger.Log ("Error parsing note XML, skipping \"{0}\": {1}",
+					Logger.Error ("Error parsing note XML, skipping \"{0}\": {1}",
 					            file_path,
 					            e.Message);
-				}
+				} catch (System.IO.IOException e) {
+					Logger.Error ("Note {0} can not be loaded - file corrupted?: {1}",
+					            file_path,
+					            e.Message);
+					Gtk.MessageDialog md =
+					  new Gtk.MessageDialog(null,Gtk.DialogFlags.DestroyWithParent,
+					                      Gtk.MessageType.Error,
+					                      Gtk.ButtonsType.Close,
+					                      "Skipping a note.\n {0} can not be loaded - Error loading file!",
+					                      file_path
+					                     );
+					md.Run();
+					md.Destroy();
+				} catch (System.UnauthorizedAccessException e) {
+					Logger.Error ("Note {0} can not be loaded - access denied: {1}",
+					            file_path,
+					            e.Message);
+					Gtk.MessageDialog md =
+					  new Gtk.MessageDialog(null,Gtk.DialogFlags.DestroyWithParent,
+					                      Gtk.MessageType.Error,
+					                      Gtk.ButtonsType.Close,
+					                      "Skipping a note.\n {0} can not be loaded - Access denied!",
+					                      file_path
+					                     );
+					md.Run();
+					md.Destroy();
+				}	
 			}
 			
 			notes.Sort (new CompareDates ());
@@ -362,6 +396,9 @@ Ciao!");
 				if (start_note != null)
 					Preferences.Set (Preferences.START_NOTE_URI, start_note.Uri);
 			}
+
+			if (NotesLoaded != null)
+				NotesLoaded (this, EventArgs.Empty);
 		}
 
 		void OnExitingEvent (object sender, EventArgs args)
@@ -376,7 +413,7 @@ Ciao!");
 				}
 			}
 
-			Logger.Log ("Saving unsaved notes...");
+			Logger.Debug ("Saving unsaved notes...");
 			
 			// Use a copy of the notes to prevent bug #510442 (crash on exit
 			// when iterating the notes to save them.
@@ -412,7 +449,7 @@ Ciao!");
 			notes.Remove (note);
 			note.Delete ();
 
-			Logger.Log ("Deleting note '{0}'.", note.Title);
+			Logger.Debug ("Deleting note '{0}'.", note.Title);
 
 			if (NoteDeleted != null)
 				NoteDeleted (this, note);
@@ -547,6 +584,7 @@ Ciao!");
 			new_note.XmlContent = xml_content;
 			new_note.Renamed += OnNoteRename;
 			new_note.Saved += OnNoteSave;
+			new_note.BufferChanged += OnBufferChanged;
 
 			notes.Add (new_note);
 
@@ -685,6 +723,8 @@ Ciao!");
 		public event NotesChangedHandler NoteAdded;
 		public event NoteRenameHandler NoteRenamed;
 		public event NoteSavedHandler NoteSaved;
+		public event Action<Note> NoteBufferChanged;
+		public event EventHandler NotesLoaded;
 	}
 
 	public class TrieController
@@ -724,6 +764,8 @@ Ciao!");
 			foreach (Note note in manager.Notes) {
 				title_trie.AddKeyword (note.Title, note);
 			}
+
+			title_trie.ComputeFailureGraph ();
 		}
 
 		public TrieTree TitleTrie
